@@ -2,8 +2,8 @@ import json
 import logging
 
 from zygoat.components import Component
-from zygoat.constants import Projects, Phases
-from zygoat.utils.shell import run
+from zygoat.constants import Projects, Phases, Images
+from zygoat.utils.shell import docker_run
 from zygoat.utils.files import use_dir
 
 log = logging.getLogger()
@@ -11,10 +11,10 @@ log = logging.getLogger()
 
 class PrettyQuick(Component):
     def create(self):
-        with use_dir(Projects.FRONTEND):
-            log.info("Installing pretty-quick into frontend project")
-            run(["yarn", "add", "--dev", "pretty-quick"])
+        log.info("Installing pretty-quick into frontend project")
+        docker_run(["yarn", "add", "--dev", "pretty-quick"], Images.NODE, Projects.FRONTEND)
 
+        with use_dir(Projects.FRONTEND):
             log.info("Adding pretty-quick lint command")
             with open("package.json") as f:
                 data = json.load(f)
